@@ -1,4 +1,4 @@
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -35,6 +35,6 @@ Attributes:
 AUTHOR = "Kenneth J. Pronovici"
 EMAIL = "pronovic@ieee.org"
 COPYRIGHT = "2004-2022"
-VERSION = "3.6.5"
-DATE = "30 Apr 2022"
+VERSION = "3.6.6"
+DATE = "05 Sep 2022"
 URL = "https://github.com/pronovic/cedar-backup3"
